# v0.9.0
- Refactored main analyzers to be as generic as possible

# v0.8.0
- Added LCOM4 metrics

# v0.7.3
- Added metrics explanations page

# v0.7.2
- Fix halstead and import tests

# v0.7.1
- Refactor to make analyzers more generic
- Fix coupling for php

# v0.7.0
- Added CSV report output

# v0.6.0
- Added CLI report output
- Fixed wrong values on index page

# v0.5.0
- Added cognitive complexity (for python & php)

# v0.4.2
- Fix issue in test case

# v0.4.1
- Add simhash to dependenies

# v0.4.0
- Added Coupling and instability calculation (fine for python, buggy for php, untested for typescript)
- Added skeleton for file duplication detection
- Added Basic Code smell detection & html reporting (fine for python, buggy for php, untested for typescript)

# v0.3.10
- Fix avg function loc for file
- Fix method size segment in file view
- Improve visuals of file view
- Fix width issue in git view

# v0.3.9
- Fix styling in git_analysis so tables are readable
- Add variables in paths

# v0.3.8
- Fix MI for empty functions
- Circumventing bug in lizard regarding use function statements in PHP

# v0.3.7
- Added Favicon
- Circumventing bug in lizard regarding traits in PHP

# v0.3.6
- Fix dependency license distribution chart 

# v0.3.5
- Bump templater version
- Fix path resolving
- Fix error during trends rendering

# v0.3.4
- Fix version info after install

# v0.3.3
- Fix missing templates after install

# v0.3.2
- Add missing dependency

# v0.3.1
- Add yaml config support
- Clean up html page rendering

# v0.3.0
- Add trends

# v0.2.8
- Fix version status in pip analysis
- Add json report

# v0.2.7
- fix files

# v0.2.6
- Fully move namespace, fix script

# v0.2.5
- Change name of project to metripy

# v0.2.4
- Change name of project to py_codemetrics

# v0.2.3
- Fix test action by dropping 3.9, 3.10 support

# v0.2.2
- Fix test action

# v0.2.1
- Added git metrics json reporting
- Added some first tests
- Added github actions

# v0.2.0
- Added code analysis of typescript
- Added npm dependencies analysis

# v0.1.0
- Added main structure
- Added config loading and parsing
- Added code analysis of python
- Added code analysis of php
- Added git analysis
- Added composer dependencies analysis
- Added pip dependencies analysis
- Added html report dashboard, file insights, git insights, dependency insights
